@@ -1,11 +1,11 @@
 package App::TestOnTap;
 
-use 5.010;
+use 5.010_001;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 my $version = $VERSION;
 $VERSION = eval $VERSION;
 
