@@ -121,7 +121,7 @@ sub endTestRun
 	$self->__save("$self->{root}/data/meta", $meta);
 }
 
-sub openTapHandle
+sub openTAPHandle
 {
 	my $self = shift;
 	my $testPath = slashify(shift, '/');
@@ -135,6 +135,17 @@ sub openTapHandle
 	return $h;
 }
 
+sub closeTAPHandle
+{
+	my $self = shift;
+	my $parser = shift;
+	
+	my $spool_handle = $parser->delete_spool;
+	close($spool_handle) if $spool_handle;
+	
+	return;
+}
+
 sub getResultCollector
 {
 	my $self = shift;
